##  1. Add the Subsection for Maturity in the Business Capability Fact Sheet
To add a new subsection, follow these steps:
i. Navigate to Administration > Meta Model Configuration, and choose the Business Capability Fact Sheet.
ii. Select the Information section in the Fact Sheet. Once selected, a + Add subsection button will appear; click on it.
iii. On the right-side panel, fill in “maturity” as the unique ID for the field Key and click Create.
iv. Go to the Manage Translation tab (Globe icon) on the right-side panel. Fill in the following values to the Label and Help Text fields:
Field | Value
---|---
Label: | Maturity
Help Text (Optional): | What is the current and target maturity level of this {{factSheet}}?


![Adding new subsection to Business Capability Fact Sheet.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274fa4587a4410149332872ff93589d0_LowRes.gif)
Adding new subsection to Business Capability Fact Sheet.
v. Click Show changes and then Apply.
The new subsection ‘Maturity’ is created.
